%%
%% This is file `beamerouterthemesmoothtree-xetex-bidi.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% bidi.dtx  (with options: `table,beamerouterthemesmoothtree-xetex-bidi.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2007--2026  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 

%% \CheckSum{54343}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ProvidesFile{beamerouterthemesmoothtree-xetex-bidi.def}[2022/06/09 v0.1 bidi adaptations for beamerouterthemesmoothtree package for XeTeX engine]
\bidi@csundef{beamer@@tmpop@headline@smoothtree theme}

\bidi@csundef{beamer@@tmpop@frametitle@smoothtree theme}

\defbeamertemplate*{headline}{smoothtree theme}
{%
  \pgfuseshading{beamer@treeshade}%
  \vskip-0.05ex%
  \begin{beamercolorbox}[wd=\paperwidth,ht=1ex,dp=0ex]{empty}
  \begin{pgfpicture}
    \begin{pgfscope}%
      \pgfsetfillcolor{subsection in head/foot.bg}%
      \pgfpathrectangle{\pgfpoint{-.5\paperwidth}{-0.5ex}}{\pgfpoint{\paperwidth}{1ex}}%
      \pgfsetfading{beamer@belowframetitlemask}{}%
      \pgfusepath{fill}%
    \end{pgfscope}%
  \end{pgfpicture}%
  \end{beamercolorbox}%
  \vskip-9.15ex%
  \if@RTL
  \begin{beamercolorbox}[wd=\paperwidth,ht=1.125ex,dp=1.125ex,ignorebg,%
    rightskip=.3cm,leftskip=.3cm plus1fil]{title in head/foot}
  \else
  \begin{beamercolorbox}[wd=\paperwidth,ht=1.125ex,dp=1.125ex,ignorebg,%
    leftskip=.3cm,rightskip=.3cm plus1fil]{title in head/foot}
    \fi
    \usebeamerfont{title in head/foot}\insertshorttitle
  \end{beamercolorbox}
  \if@RTL
    \begin{beamercolorbox}[wd=\paperwidth,ht=2.125ex,dp=1.125ex,ignorebg,%
    rightskip=.3cm,leftskip=.3cm plus1fil]{section in head/foot}
  \else
  \begin{beamercolorbox}[wd=\paperwidth,ht=2.125ex,dp=1.125ex,ignorebg,%
    leftskip=.3cm,rightskip=.3cm plus1fil]{section in head/foot}
    \fi
    \usebeamerfont{section in head/foot}%
    \hskip6pt\insertsectionhead
  \end{beamercolorbox}
  \if@RTL
  \begin{beamercolorbox}[wd=\paperwidth,ht=2.125ex,dp=1.125ex,ignorebg,%
      rightskip=.3cm,leftskip=.3cm plus1fil]{subsection in head/foot}
  \else
  \begin{beamercolorbox}[wd=\paperwidth,ht=2.125ex,dp=1.125ex,ignorebg,%
      leftskip=.3cm,rightskip=.3cm plus1fil]{subsection in head/foot}
    \fi
    \usebeamerfont{subsection in head/foot}%
    \hskip12pt\insertsubsectionhead
  \end{beamercolorbox}
  \vskip-0.4ex%
}

\defbeamertemplate*{frametitle}{smoothtree theme}
{%
  \nointerlineskip%
  \vskip-0.05ex%
  \usebeamerfont{headline}%
  \begin{beamercolorbox}[wd=\paperwidth,ht=0.85ex,dp=0ex]{empty}
    \pgfuseshading{beamer@aboveframetitle}%
  \end{beamercolorbox}
  \nointerlineskip%
  \if@RTL
  \begin{beamercolorbox}[wd=\paperwidth,rightskip=.935cm,leftskip=.3cm plus1fil]{frametitle}
 \else
  \begin{beamercolorbox}[wd=\paperwidth,leftskip=.935cm,rightskip=.3cm plus1fil]{frametitle}
  \fi
    \vskip-1.2ex%
    \usebeamerfont*{frametitle}\strut\insertframetitle%
      \ifx\insertframesubtitle\@empty%
        \strut\par%
      \else
        \par{\usebeamerfont*{framesubtitle}{\usebeamercolor[fg]{framesubtitle}\strut\insertframesubtitle}\strut\par}%
      \fi%%
    \usebeamerfont{headline}%
  \end{beamercolorbox}%
  \nointerlineskip
  \vskip-0.2ex%
  \begin{beamercolorbox}[wd=\paperwidth,ht=1ex,dp=0ex]{empty}
  \begin{pgfpicture}
    \begin{pgfscope}%
      \pgfsetfillcolor{frametitle.bg}%
      \pgfpathrectangle{\pgfpoint{-.5\paperwidth}{-0.5ex}}{\pgfpoint{\paperwidth}{1ex}}%
      \pgfsetfading{beamer@belowframetitlemask}{}%
      \pgfusepath{fill}%
    \end{pgfscope}%
  \end{pgfpicture}%
  \end{beamercolorbox}%
}

\AtBeginDocument{%
  \setbeamertemplate{frametitle}[smoothtree theme]%
}

\endinput
%%
%% End of file `beamerouterthemesmoothtree-xetex-bidi.def'.
